## Changelog

### [v0.1.2]
 - support both Python 3.4 and 2.7

### [v0.1.1]
 - setup.py is now Python 3 compatible
 - general tidiness:
   - added installation instructions to [README.md](README.md)
   - removed unused module `pydgq.utils.ptrwrap`
   - removed unused dependencies (oops)
   - use correct compile flags for all modules
   - updated [TODO.md](TODO.md) to reflect the current status of the project


### [v0.1.0]
 - initial release as separate project (cleaned up and generalized)

